@@ -319,33 +319,68 @@ def info(topic,lines=3):
     spe = wikipedia.summary(topic, sentences = lines)
     print(spe)
     
-def playonyt(title):
-    '''Opens YouTube video with following title'''
-    print("Due to recent changes in the YouTube, this function is not working, I am working to fix it.")
-    url = 'https://www.youtube.com/results?q=' + title
-    sc = requests.get(url)
-    sctext = sc.text
+def playonyt(topic):
+    """Will play video on following topic, takes about 10 to 15 seconds to load"""
+    url = 'https://www.youtube.com/results?q=' + topic
+    options = webdriver.ChromeOptions()
+    options.add_argument("--headless")
+    try:
+        with open("pywhatkit_txtfile.txt") as file:
+            for lines in file:
+                    if "selpath" in lines:
+                        path = lines.replace("selpath : ","")
+            path = path.strip()
+        driver = webdriver.Chrome(path,options=options)
+    except:
+        raise Exception("Chrome driver not found, call pywhatkit.help()")
+    req = driver.get(url)
+    sctext = driver.page_source
+    driver.quit()
     soup = BeautifulSoup(sctext,"html.parser")
-    songs = soup.findAll("div",{"class":"yt-lockup-video"})
-    song = songs[0].contents[0].contents[0].contents[0]
-    songurl = song["href"]
-    web.open("https://www.youtube.com"+songurl)
+    try:
+        songs = soup.findAll("a",{"id":"video-title"})
+        song = songs[0]
+        songurl = song['href']
+        web.open("https://www.youtube.com"+songurl)
+    except:
+        raise Exception("Video not found")
 
 def search(topic):
     '''Searches about the topic on Google'''
     link = 'https://www.google.com/search?q={}'.format(topic)
     web.open(link)
 
-def manual():
+def help():
     """User manual of pywhatkit library"""
     print("""How to use the new functions:
-NOTE : To use those functions, you must have Google Chrome installed and updated
+
+NOTE : To use new functions, you must have Google Chrome installed and updated
 1. Download and extract the current stable release of chromedriver from https://chromedriver.chromium.org/.
 2. Open the downloaded file and search for an application named chromedrive, copy its path,
    for windows, it should look like this - C:/Users/.../chromedriver.exe.
 3. Call pywhatkit.add_driver_path(path) and pass the copied path as argument, if path is valid, a black window along with chrome will open and close
 4. Now call pywhatkit.load_QRcode() function and scan the QR code.
-5. You are all set. Now call the desired function. All the information have been saved and you don't to do the same thing again.""")
+5. You are all set. Now call the desired function. All the information have been saved and you don't to do the same thing again.
+
+
+SOME COMMON ERRORS and HOW TO FIX THEM:
+
+1. CountryCodeException("Country code missing from phone_no")
+-> To Fix this issue you need to add country code to the phone number, it satrts with "+".
+
+2. CallTimeException("Call time must be greater than one minute as web.whatsapp.com takes some time to load")
+-> Make sure the there is a difference of at least 60 seconds between current time and time you want to send message at.
+
+3. Driver not found error
+-> To fix this issue you need to download the driver of your respective browser.
+-> You can download if from the given link : https://chromedriver.chromium.org/downloads
+-> After downloading extract them and open the downloaded file and search for an application named chromedrive, copy its path,
+   for windows, it should look like this - C:/Users/.../chromedriver.exe.
+-> Call pywhatkit.add_driver_path(path) and pass the copied path as argument, if path is valid, a black window along with chrome will open and close.
+
+NOTE : You must have Chrome browser installed, I will add support for other browsers soon.
+""")
+
 try : 
     requests.get("https://www.google.com")
     current = time.time()
@@ -363,13 +398,10 @@ try :
 
 except:
     file = open("pywhatkit_txtfile.txt","w")
-    print("Hello from the creator of pywhatkit, Ankit Raj Mahapatra.\nKindly do report bug if any")
-    print("All the messages followed by '***' shall be considered for the first time only")
-    print("Meaning, you need to call the mentioned functions for once only")
-    print("In order to use some functions of this library, you need to have distribution of chromedriver installed")
-    print("Call pywhatkit.manual() for more information")
-    print("Download the current stable release from https://chromedriver.chromium.org/")
-    print("This message will not be shown again.:)")
+    print("""Hello from the creator of pywhatkit, Ankit Raj Mahapatra.\nKindly do report bug if any
+What's new:
+1. Fixed playonyt() function.
+2. Added some new functions, to know how to use them check pywhatkit.help().""")
     file.write("--------------------\n")
     file.close()
     file = None
